get_catchment_csv_row

Function get_catchment_csv_row 

pub fn get_catchment_csv_row(
    reply: MeasurementReply,
    rx_id: &u32,
    worker_map: &BiHashMap<u32, String>,
    origin_id: u32,
) -> Vec<String>
Get the result (csv row) from a Reply message

Arguments

  • result - The Reply that is being written to this row
  • rx_id - The worker ID of the receiver
  • worker_map - A map of worker IDs to hostnames, used to convert worker IDs to hostnames in the results
  • origin_id - Origin ID associated with the reply (0 if a single origin is used)

Returns

A vector of strings representing the row in the CSV file